These files are based on the
`Chemical Component Dictionary <https://www.wwpdb.org/data/ccd>`_
and were created using ``setup_ccd.py``.

To keep the size of the repository small, the original commit should be
rewritten, if the formats of the affected files are compatible with the
original ones.
The name of the commit is ``Add CCD dataset``.